Brightway2-analyzer
===================

This is a set of tools to analyze results of life cycle assessment (LCA) calculations. It is part of the `Brightway2 LCA framework <http://brightwaylca.org>`_. `Online documentation <https://bw2analyzer.readthedocs.org/en/latest/>`_ is available, and the source code is hosted on `Bitucket <https://bitbucket.org/cmutel/brightway2-analyzer>`_.
